(v1.8.1)=
### 1.8.1 {small}`2021-07-07`

#### Bug fixes

- Fixed reproducibility of {func}`scanpy.tl.score_genes`. Calculation and output is now float64 type.  {pr}`1890` {smaller}`I Kucinski`
- Workarounds for some changes/ bugs in pandas 1.3 {pr}`1918` {smaller}`I Virshup`
- Fixed bug where `sc.pl.paga_compare` could mislabel nodes on the paga graph {pr}`1898` {smaller}`I Virshup`
- Fixed handling of `use_raw` with {func}`scanpy.tl.rank_genes_groups` {pr}`1934` {smaller}`I Virshup`
